@@ -4,4 +4,6 @@ use serde_derive::Deserialize;
 pub struct Manifest {
     pub root: String,
     pub sku: String,
+    #[serde(default)]
+    pub ignore: Vec<String>,
 }
